package com.telpo.dipperposition;

import com.alibaba.nacos.api.NacosFactory;
import com.alibaba.nacos.api.config.ConfigService;
import com.alibaba.nacos.api.config.listener.Listener;
import com.alibaba.nacos.api.PropertyKeyConst;
import com.alibaba.nacos.api.exception.NacosException;
import com.telpo.dipperposition.server.DipperPositionServer;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.context.properties.ConfigurationPropertiesScan;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.cloud.client.discovery.EnableDiscoveryClient;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;

import java.util.Properties;
import java.util.concurrent.Executor;

/**
 * @program: gateway
 * @description: 网关启动类
 * @author: linwl
 * @create: 2020-06-18 16:39
 */
@SpringBootApplication
@EnableDiscoveryClient
@ConfigurationPropertiesScan
@EnableAsync
@EnableScheduling
@Slf4j
public class DipperPositionApplication {

  public static void main(String[] args) {
    log.info("北斗定位服务开始!");
    SpringApplication.run(DipperPositionApplication.class, args);
    log.info("北斗定位服务启动!");
    try {
      test();
    } catch (Exception e) {
      log.error(e.getMessage());
    }
    //启动服务端
    DipperPositionServer nettyServer = new DipperPositionServer();
    nettyServer.startTimeAsnc();
    nettyServer.startPosAsnc();
    nettyServer.startStarsAsnc();
  }

  private static void test() throws NacosException {
    String serverAddr = "172.16.192.26";
    String dataId = "dipperposition-service";
    String group = "DEFAULT_GROUP";
    Properties properties = new Properties();
    properties.put(PropertyKeyConst.SERVER_ADDR, serverAddr);
    ConfigService configService = NacosFactory.createConfigService(properties);
    String content = configService.getConfig(dataId, group, 5000);
    System.out.println(content);
  }
}
