package com.telpo.dipperposition.server;

import com.alibaba.nacos.api.NacosFactory;
import com.alibaba.nacos.api.PropertyKeyConst;
import com.alibaba.nacos.api.config.ConfigService;
import com.alibaba.nacos.api.exception.NacosException;
import com.telpo.dipperposition.co.PositionConfigInfo;
import com.telpo.dipperposition.config.AsyncExecutorConfig;
import com.telpo.dipperposition.config.PositionConfig;
import com.telpo.dipperposition.handler.ServerChannelInitializer;
import com.telpo.dipperposition.service.IDipperDataAsyncTaskService;
import io.netty.bootstrap.ServerBootstrap;
import io.netty.channel.ChannelFuture;
import io.netty.channel.ChannelOption;
import io.netty.channel.EventLoopGroup;
import io.netty.channel.nio.NioEventLoopGroup;
import io.netty.channel.socket.nio.NioServerSocketChannel;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.beans.factory.config.YamlMapFactoryBean;

import java.io.InputStream;
import java.net.InetSocketAddress;
import java.util.Properties;


/**
 * @program: DipperPositionServer
 * @description: 北斗定位
 * @author: king
 * @create: 2021-01-13 14:01
 */
@Slf4j
public class DipperPositionServer {

    @Autowired PositionConfigInfo positionConfigInfo;
    private String serverAddr="172.16.192.26";
    private String timeAsycServerPort="9011";
    private String posAsycServerPort="9013";
    private String starsAsycServerPort="9012";

    public DipperPositionServer() throws NacosException {
        String serverAddr = positionConfigInfo.getServerAddr();
        log.info("Config serverAddr is " + serverAddr);
    }
    /*
     * 时间同步进程线程
     */
    public void startTimeAsnc() {

        //new 一个主线程组
        EventLoopGroup mainThreadGroup = new NioEventLoopGroup(1);
        //new 一个工作线程组
        EventLoopGroup workThreadGroup = new NioEventLoopGroup(200);
        InetSocketAddress socketAddress = new InetSocketAddress(serverAddr,
                Integer.parseInt(timeAsycServerPort));
        ServerBootstrap bootstrap = new ServerBootstrap()
                .group(mainThreadGroup, workThreadGroup)
                .channel(NioServerSocketChannel.class)
                .childHandler(new ServerChannelInitializer())
                .localAddress(socketAddress)
                //设置队列大小
                .option(ChannelOption.SO_BACKLOG, 1024)
                // 两小时内没有数据的通信时,TCP会自动发送一个活动探测数据报文
                .childOption(ChannelOption.SO_KEEPALIVE, true);


        //绑定端口,开始接收进来的连接
        try {
            ChannelFuture future = bootstrap.bind(socketAddress).sync();
            log.info("服务器启动开始监听端口: {}", socketAddress.getPort());


            future.channel().closeFuture().sync();
        } catch (InterruptedException e) {
            e.printStackTrace();
        } finally {
            //关闭主线程组
            mainThreadGroup.shutdownGracefully();
            //关闭工作线程组
            workThreadGroup.shutdownGracefully();
        }
    }

    /*
     * 时间同步进程线程
     */
    public void startPosAsnc() {

        //new 一个主线程组
        EventLoopGroup mainThreadGroup = new NioEventLoopGroup(1);
        //new 一个工作线程组
        EventLoopGroup workThreadGroup = new NioEventLoopGroup(200);
        InetSocketAddress socketAddress = new InetSocketAddress(serverAddr,
                Integer.parseInt(posAsycServerPort));
        ServerBootstrap bootstrap = new ServerBootstrap()
                .group(mainThreadGroup, workThreadGroup)
                .channel(NioServerSocketChannel.class)
                .childHandler(new ServerChannelInitializer())
                .localAddress(socketAddress)
                //设置队列大小
                .option(ChannelOption.SO_BACKLOG, 1024)
                // 两小时内没有数据的通信时,TCP会自动发送一个活动探测数据报文
                .childOption(ChannelOption.SO_KEEPALIVE, true);


        //绑定端口,开始接收进来的连接
        try {
            ChannelFuture future = bootstrap.bind(socketAddress).sync();
            log.info("服务器启动开始监听端口: {}", socketAddress.getPort());


            future.channel().closeFuture().sync();
        } catch (InterruptedException e) {
            e.printStackTrace();
        } finally {
            //关闭主线程组
            mainThreadGroup.shutdownGracefully();
            //关闭工作线程组
            workThreadGroup.shutdownGracefully();
        }
    }


    /*
     * 星历同步进程线程
     */
    public void startStarsAsnc() {

        //new 一个主线程组
        EventLoopGroup mainThreadGroup = new NioEventLoopGroup(1);
        //new 一个工作线程组
        EventLoopGroup workThreadGroup = new NioEventLoopGroup(200);
        InetSocketAddress socketAddress = new InetSocketAddress(serverAddr,
                Integer.parseInt(starsAsycServerPort));
        ServerBootstrap bootstrap = new ServerBootstrap()
                .group(mainThreadGroup, workThreadGroup)
                .channel(NioServerSocketChannel.class)
                .childHandler(new ServerChannelInitializer())
                .localAddress(socketAddress)
                //设置队列大小
                .option(ChannelOption.SO_BACKLOG, 1024)
                // 两小时内没有数据的通信时,TCP会自动发送一个活动探测数据报文
                .childOption(ChannelOption.SO_KEEPALIVE, true);


        //绑定端口,开始接收进来的连接
        try {
            ChannelFuture future = bootstrap.bind(socketAddress).sync();
            log.info("服务器启动开始监听端口: {}", socketAddress.getPort());


            future.channel().closeFuture().sync();
        } catch (InterruptedException e) {
            e.printStackTrace();
        } finally {
            //关闭主线程组
            mainThreadGroup.shutdownGracefully();
            //关闭工作线程组
            workThreadGroup.shutdownGracefully();
        }
    }
}
